/* ccgo: go/nc.hh
 *
 * Copyright 2004 Chun-Chung Chen <cjj@u.washington.edu>
 *
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef GO_NC_HH
#define GO_NC_HH

#include <go/game.hh>
#include <string>

namespace Nc {
	class Entry { // multiple line text entry
	public:
		Entry();
		Entry(int x, int y, int width, int height);
		~Entry();

		void set_size(int x, int y, int width, int height);
		void draw_buf();
		void set_cursor();
		bool process_key(int c);
		std::string get_text();
		void set_text(const std::string & text);
		void set_guide(bool guide_shown);
	private:
		std::vector<std::string> buf;

		bool shown;
		// window geometry
		int entx;
		int enty;
		int entw;
		int enth;

		// cursor position
		int entl;
		int entc;

		// buffer offset
		int curl;
		int curc;
		int top;
		int topc;

		bool need_redraw;
		bool show_guide;
	};

	class Walk : // There can be only one instance for Nc::Walk
		virtual public ccgo::PathWalk
	{
	public:
		Walk();
		~Walk();
		virtual void set_node(ccgo::Node * node);
		bool process_key(int c);
		void loop();
	protected:
		void resize();
		void update_loc(int loc);
		void show_board();
		void show_mark();
		void hide_mark();
		void show_status();
		void show_map();
		void show_comment();

		virtual void clear();
		virtual void set_state(int loc, State state);

		void clear_message();
		void message(const std::string & s);
	private:
		static int cnt;
		int sz;
		bool board_shown;
		bool status_shown;
		bool map_shown;
		bool comment_shown;
		bool edit_comment;
		int cy;
		int cx;
		bool er;
		ccgo::Game * g;
		int mx;
		int my;
		int bxs;
		int sxs;
		bool handi;
		Entry te;
		std::set<int> ko; // ko mark on board
	};
}
#endif // GO_NC_HH
