/* ccgo: go/nctest.cc
 *
 * Copyright 2004 Chun-Chung Chen <cjj@u.washington.edu>
 *
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include <nc.hh>
#include <arg.hh>
#include <debug.hh>
#include <go/sgf.hh>
#include <sstream>
#include <fstream>
#include <iomanip>

using namespace std;

int main(int argc, char * argv[])
{
	arg::Parser p;

	p.add_opt('d', "debug")
		.store(arg::SV(& debug_level))
		.help("setting debug level to NUM", "NUM");

	string sgf_file;
	p.add_opt('f', "sgf-file")
		.store(arg::SV(& sgf_file))
		.help("open FILE as SGF file", "FILE");
	p.add_opt_help();
	p.add_opt_version(string("ccGo ") + VERSION);

	p.parse(argc, argv);

	ccgo::Game * g = 0;
	if (sgf_file.size()) {
		msg(DBG_INFO) << "loading sgf file: " << sgf_file << '\n';
		fstream f(sgf_file.c_str(), ios::in);
		if (f) g = ccgo::load_sgf(f);
		msg(DBG_DEBUG) << "sgf file loaded\n";
	}
	
	if (! g) for (vector<string>::const_iterator i = p.args().begin(); i != p.args().end(); i ++) {
		const string & s = * i;
		if (s.length() < 4) continue;
		if (s.substr(s.length() - 4) == ".sgf") {
			msg(DBG_INFO) << "loading sgf file: " << string(sgf_file) << "\n";
			fstream f(s.c_str(), ios::in);
			if (f) g = ccgo::load_sgf(f);
			msg(DBG_DEBUG) << "sgf loaded\n";
			break;
		}
	}

	if (! g) {
		g = new ccgo::Game;
		g->set_init(19);
	}


	Nc::Walk nw;
	nw.set_node(g);
	nw.loop();
	delete g;
	g = 0;
	return 0;
}

